@@ -173,8 +173,9 @@ class FacebookTokenManager(object):
         return access_token, expires_in_seconds
 
     def debug_token(self, token):
-        graph = utils.get_application_graph()
-        response = graph.get('v2.1/debug_token', input_token=token)
+        version = getattr(settings, 'FACEBOOK_API_VERSION', '2.1')
+        graph = utils.get_application_graph(version)
+        response = graph.get('/debug_token', input_token=token)
         parsed_response = forms.parse_facebook_response(response, token)
         if parsed_response.is_valid:
             data = parsed_response.parsed_data
